<?php
   class clsTdoc extends BDConexion
   {
     function clsTdoc()
     {
       $this->conectar();
     }
     function getTdoc()
     {
       $ssql="select idtipodoc,tddesc ";
       $ssql.=" From tipodoc ";       
       return $this->BDConsulta($ssql);
     }
	 function getNumTra()
     {
       $ssql="select campo,valor ";
       $ssql.=" From parametro where campo='numtramite'";       
       return $this->BDConsulta($ssql);
     }
	 function devuelveNumTra($numtra)
     {
       $ssql="select idtradoc ";
       $ssql.=" From tradoc where numtra=$numtra";       
       return $this->BDConsulta($ssql);
     }
	 function devuelveDoc($idtradoc)
     {
       $ssql="select iddocdigital,docdigital ";
       $ssql.=" From docdigital where idtradoc=$idtradoc";       
       return $this->BDConsulta($ssql);
     }
	 function devuelveEstado($iddtradoc)
     {
       $ssql="select iddtradoc,estado ";
       $ssql.=" From detalletradoc where iddtradoc=$iddtradoc";       
       return $this->BDConsulta($ssql);
     }
	 function ListarDocInt($idtradoc,$origendoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.prioridad,td.confidencial,td.asunto,td.numdoc,dt.de,dt.estado,tp.tddesc,dt.fechae,td.numfolios,td.obser ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and td.idtradoc=$idtradoc and td.origendoc='$origendoc' and dt.para='$para'";       
       return $this->BDConsulta($ssql);
     }
	 function ListarDocEmitidos($tipotradoc,$origendoc,$de,$idatdoc)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.prioridad,td.confidencial,td.asunto,td.numdoc,dt.de,dt.estado,tp.tddesc,dt.fechae,td.numfolios,td.obser ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and ad.idatdoc=$idatdoc and td.tipotradoc='$tipotradoc' and td.origendoc='$origendoc' and dt.de='$de' group by td.numtra";       
       return $this->BDConsulta($ssql);
     }
	 function ListarDocEmitidosPag($tipotradoc,$origendoc,$de,$idatdoc,$regini,$regxpag)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.prioridad,td.confidencial,td.asunto,td.numdoc,dt.de,dt.estado,tp.tddesc,dt.fechae,td.numfolios,td.obser ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and ad.idatdoc=$idatdoc and td.tipotradoc='$tipotradoc' and td.origendoc='$origendoc' and dt.de='$de' group by td.numtra limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function ListarDocEmitidosT($tipotradoc,$origendoc,$de,$idatdoc)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.prioridad,td.confidencial,td.asunto,td.numdoc,dt.de,dt.estado,tp.tddesc,dt.fechae,td.numfolios,td.obser ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and ad.idatdoc=$idatdoc and td.tipotradoc='$tipotradoc' and td.origendoc='$origendoc' and dt.de='$de' group by td.numtra ";       
       return $this->BDConsulta($ssql);
     }
	 function ListarTodosDocInt($origendoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,dt.de,tp.tddesc,dt.fechae,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and td.origendoc='$origendoc' and dt.para='$para'";       
       return $this->BDConsulta($ssql);
     }
	 function ListarTodosDocIntPag($origendoc,$para,$regini,$regxpag)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,dt.de,tp.tddesc,dt.fechae,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and td.origendoc='$origendoc' and dt.para='$para'  limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function ListarTodosDocIntT($origendoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,dt.de,tp.tddesc,dt.fechae,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt,tipodoc as tp,asigna_tdoc as ad where td.idtradoc=dt.idtradoc and ad.idatdoc=td.idatdoc and tp.idtipodoc=ad.idtdoc and td.origendoc='$origendoc' and dt.para='$para'  ";       
       return $this->BDConsulta($ssql);
     }
	 function devuelveExistencia($origendoc,$tipotradoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,td.tipo,dt.de,dt.fechar,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt where td.idtradoc=dt.idtradoc and td.origendoc='$origendoc' and dt.para='$para' and td.tipotradoc='$tipotradoc'  ";       
	   
       return $this->BDConsulta($ssql);
     }
	 function devuelveExistenciaV($origendoc,$tipotradoc,$para,$regini,$regxpag)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,td.tipo,dt.de,dt.fechar,dt.fechae,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt where td.idtradoc=dt.idtradoc and td.origendoc='$origendoc' and dt.para='$para' and td.tipotradoc='$tipotradoc' limit $regini,$regxpag ";       
	   
       return $this->BDConsulta($ssql);
     }
	 function devuelveExistenciaT($origendoc,$tipotradoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,td.tipo,dt.de,dt.fechar,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt where td.idtradoc=dt.idtradoc and td.origendoc='$origendoc' and dt.para='$para' and td.tipotradoc='$tipotradoc' ";       
	   
       return $this->BDConsulta($ssql);
     }
	 function devuelveExistencias($numtra,$origendoc,$tipotradoc,$para)
     {
       $ssql="select dt.iddtradoc,td.idtradoc,td.numtra,td.numdoc,td.tipo,dt.de,dt.fechar,dt.estado ";
       $ssql.=" From tradoc as td,detalletradoc as dt where td.idtradoc=dt.idtradoc and td.origendoc='$origendoc' and dt.para='$para' and td.tipotradoc='$tipotradoc' and td.numtra=$numtra";       
       return $this->BDConsulta($ssql);
     }
	 function getTdocAsigna()
     {
       $ssql="select ad.idatdoc,td.tddesc ";
       $ssql.=" From asigna_tdoc as ad,areas as a,tipodoc as td where ad.idtdoc=td.idtipodoc and ad.idarea=a.idarea and ad.idarea=".$_SESSION['areaId'];       
       return $this->BDConsulta($ssql);
     }
	 function getGlosadoc($idatdoc)
     {
       $ssql="select ad.periodo,ad.correlativo,a.areaglosa,td.tddesc ";
       $ssql.=" From asigna_tdoc as ad,areas as a,tipodoc as td where ad.idtdoc=td.idtipodoc and ad.idarea=a.idarea and ad.idatdoc=".$idatdoc;       
       return $this->BDConsulta($ssql);
     }
     function getTdoccod($idtdoc)
     {
       $ssql="select idtipodoc,tddesc ";
       $ssql.=" From tipodoc where idtipodoc=".$idtdoc;       
       return $this->BDConsulta($ssql);
     }
     function getCboTdoc($tdocId)
     {
       $lista="";
       $resultado=$this->getTdoc();
       while($filas=$this->NextRow($resultado))
       {
         if($tdocId==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function getCboTdocAsigna($idatdoc)
     {
       $lista="";
       $resultado=$this->getTdocAsigna();
       while($filas=$this->NextRow($resultado))
       {
         if($idatdoc==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
     function getUsuarioId($login,$clave)
     {
       $ssql="select idusuario from Usuario where login='".$login."' and clave='".$clave."' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $idusuario=$filas[0];
       else
           $idusuario=0;
       $this->Liberar($resultado);
       return $idusuario;
     }
     function getUsuarioLogueo($idusuario)
     {
       $ssql="select nombres,apellidos,idarea ";
       $ssql.=" From Usuario Where idusuario=".$idusuario;
       return $this->BDConsulta($ssql);
     }
	 
	 function getMenuGrupo($idusuario)
     {
       $ssql="select menugrupo.nommenugrupo, menugrupo.idmenugrupo, menugrupo.archivo ";
       $ssql.=" From menu, permiso, menugrupo Where menu.idmenugrupo= menugrupo.idmenugrupo AND permiso.idmenu = menu.idmenu AND permiso.idusuario=".$idusuario." GROUP BY menugrupo.nommenugrupo, menugrupo.idmenugrupo";
       return $this->BDConsulta($ssql);
     }
	 
	 function getMenuItems($idmenugrupo,$idusuario)
     {
       $ssql="select menu.nommenu, menu.archivo, permiso.idmenu, menu.imgmenu ";
       $ssql.=" From menu, permiso Where menu.idmenugrupo=".$idmenugrupo." AND permiso.idmenu = menu.idmenu AND permiso.idusuario =".$idusuario." ORDER BY orden";
       return $this->BDConsulta($ssql);
     }
	 function registrarTdoc($tdcod,$tddesc)
     {
      $ssql="Insert Into tipodoc(tdcod,tddesc) values('$tdcod','$tddesc')";
       $this->BDConsulta($ssql);       
     }
	                            //$numtra,$numdoc,$prioridad,$confidencial,$asunto,$estado,$fechas,$horar,$numfolios,$obser,$origendoc,$tipotradoc,$tipo
	 function registrarTradocEx($numtra,$numdoc,$prioridad,$confidencial,$asunto,$estado,$fecha,$hora,$numfolios,$obser,$origendoc,$tipotradoc,$tipo)
     {
       $ssql="Insert Into tradoc(numtra,numdoc,prioridad,confidencial,asunto,estado,fecha,hora,numfolios,obser,origendoc,tipotradoc,tipo) values($numtra,'$numdoc','$prioridad','$confidencial','$asunto','$estado','$fecha','$hora',$numfolios,'$obser','$origendoc','$tipotradoc','$tipo')";
       $this->BDConsulta($ssql); 	   
	   $id=$this->UltimoId();
	   return $id; 
     }
	 function registrarTradoc($numtra,$numdoc,$idatdoc,$prioridad,$confidencial,$asunto,$estado,$fecha,$hora,$numfolios,$obser,$origendoc,$tipotradoc)
     {
       $ssql="Insert Into tradoc(numtra,numdoc,idatdoc,prioridad,confidencial,asunto,estado,fecha,hora,numfolios,obser,origendoc,tipotradoc) values($numtra,'$numdoc',$idatdoc,'$prioridad','$confidencial','$asunto','$estado','$fecha','$hora',$numfolios,'$obser','$origendoc','$tipotradoc')";
       $this->BDConsulta($ssql); 	   
	   $id=$this->UltimoId();
	   return $id; 
     }
	 function registrarDetTradoc($idtradoc,$de,$para,$tipotradoc,$prioridad,$estado,$idaccion,$fechae)
     {
       $ssql="Insert Into detalletradoc(idtradoc,de,para,tipotradoc,prioridad,estado,idaccion,fechae) values($idtradoc,'$de','$para','$tipotradoc','$prioridad','$estado',$idaccion,'$fechae')";
       $this->BDConsulta($ssql);       
     }
	 function registrarDetTradocEx($idtradoc,$de,$para,$tipotradoc,$prioridad,$estado,$fechar,$horar)
     {
       echo $ssql="Insert Into detalletradoc(idtradoc,de,para,tipotradoc,prioridad,estado,fechar,horar) values($idtradoc,'$de','$para','$tipotradoc','$prioridad','$estado','$fechar','$horar')";
       $this->BDConsulta($ssql);       
     }
	 function registrarDocDigital($idtradoc,$docdigital)
     {
       $ssql="Insert Into docdigital(idtradoc,docdigital) values($idtradoc,'$docdigital')";
       $this->BDConsulta($ssql);       
     }
	 function UpdateAsigTradoc($idatdoc,$correlativo)
     {      
	   $ssql= " Update asigna_tdoc set correlativo=$correlativo+1 ";
       $ssql.=" Where idatdoc=$idatdoc";
       $this->BDConsulta($ssql);       
     }
	 function UpdateParametro($campo,$valor)
     {      
	   $ssql= " Update parametro set valor=$valor+1 ";
       $ssql.=" Where campo='$campo'";
       $this->BDConsulta($ssql);       
     }
	 function UpdateDetalleTraDoc($iddtradoc,$estado,$fechar,$horar)
     {      
	   $ssql= " Update detalletradoc set estado='$estado',fechar='$fechar',horar='$horar' ";
       $ssql.=" Where iddtradoc=$iddtradoc";
       $this->BDConsulta($ssql);       
     }
	 function registrarTdoccod($idarea,$idtdoc,$periodo,$correlativo)
     {
      $ssql="Insert Into asigna_tdoc(idarea,idtdoc,periodo,correlativo) values($idarea,$idtdoc,$periodo,$correlativo)";
       $this->BDConsulta($ssql);       
     }
	 function listarUsuarios()
     {
       $ssql="select idusuario,apellidos,nombres ";
       $ssql.=" From usuario ";       
       return $this->BDConsulta($ssql);
     }
	 function listarUsuarioss($Like)
     {
       $ssql="select cCursoId,vNombre ";
       $ssql.=" From Curso ";
       if($Like<>"") $ssql.=" Where vNombre Like '%".$Like."%' ";
       $ssql.=" Order by vNombre";
       return $this->BDConsulta($ssql);
     }
     function getNombreUsuarioXCarnet($Carnet)
     {
       $ssql="select vNombre,vApellidoPat,vApellidoMat ";
       $ssql.=" From Usuario Where cCarnet='".$Carnet."'";
       $resultado=$this->BDConsulta($ssql);
       $fila=$this->NextRow($resultado);
       $this->Liberar($resultado);
       $Nombre=$fila[0]." ".$fila[1]." ".$fila[2];
       return $Nombre;
     }
     function getNombreUsuarioXId($UsuarioId)
     {
       $ssql="select vNombre,vApellidoPat,vApellidoMat ";
       $ssql.=" From Usuario Where nUsuarioId=".$UsuarioId;
       $resultado=$this->BDConsulta($ssql);
       $fila=$this->NextRow($resultado);
       $this->Liberar($resultado);
       $Nombre=$fila[0]." ".$fila[1]." ".$fila[2];
       return $Nombre;
     }
     function getNombreAlumnoXTransaccion($TransaccionId)
     {
       $ssql="select U.vNombre,U.vApellidoPat,U.vApellidoMat ";
       $ssql.=" From Usuario as U,Transaccion as T ";
       $ssql.=" Where U.cCarnet=T.cCarnet and T.nTransaccionId=".$TransaccionId;
       $resultado=$this->BDConsulta($ssql);
       $fila=$this->NextRow($resultado);
       $this->Liberar($resultado);
       $Nombre=$fila[0]." ".$fila[1]." ".$fila[2];
       return $Nombre;
     }

   }

?>